package DBD::Pg::pg_type;

@pg_type;

$pg_type[16] = 'bool';
$pg_type[17] = 'bytea';
$pg_type[18] = 'char';
$pg_type[19] = 'name';
$pg_type[20] = 'char16';
$pg_type[21] = 'int2';
$pg_type[22] = 'int28';
$pg_type[23] = 'int4';
$pg_type[24] = 'regproc';
$pg_type[25] = 'text';
$pg_type[26] = 'oid';
$pg_type[27] = 'tid';
$pg_type[28] = 'xid';
$pg_type[29] = 'cid';
$pg_type[30] = 'oid8';
$pg_type[32] = 'SET';
$pg_type[210] = 'smgr';
$pg_type[409] = 'char2';
$pg_type[410] = 'char4';
$pg_type[411] = 'char8';
$pg_type[600] = 'point';
$pg_type[601] = 'lseg';
$pg_type[602] = 'path';
$pg_type[603] = 'box';
$pg_type[604] = 'polygon';
$pg_type[605] = 'filename';
$pg_type[628] = 'line';
$pg_type[629] = '_line';
$pg_type[700] = 'float4';
$pg_type[701] = 'float8';
$pg_type[702] = 'abstime';
$pg_type[703] = 'reltime';
$pg_type[704] = 'tinterval';
$pg_type[705] = 'unknown';
$pg_type[718] = 'circle';
$pg_type[719] = '_circle';
$pg_type[790] = 'money';
$pg_type[791] = '_money';
$pg_type[810] = 'oidint2';
$pg_type[910] = 'oidint4';
$pg_type[911] = 'oidname';
$pg_type[1000] = '_bool';
$pg_type[1001] = '_bytea';
$pg_type[1002] = '_char';
$pg_type[1003] = '_name';
$pg_type[1004] = '_char16';
$pg_type[1005] = '_int2';
$pg_type[1006] = '_int28';
$pg_type[1007] = '_int4';
$pg_type[1008] = '_regproc';
$pg_type[1009] = '_text';
$pg_type[1028] = '_oid';
$pg_type[1010] = '_tid';
$pg_type[1011] = '_xid';
$pg_type[1012] = '_cid';
$pg_type[1013] = '_oid8';
$pg_type[1014] = '_lock';
$pg_type[1015] = '_stub';
$pg_type[1016] = '_ref';
$pg_type[1017] = '_point';
$pg_type[1018] = '_lseg';
$pg_type[1019] = '_path';
$pg_type[1020] = '_box';
$pg_type[1021] = '_float4';
$pg_type[1022] = '_float8';
$pg_type[1023] = '_abstime';
$pg_type[1024] = '_reltime';
$pg_type[1025] = '_tinterval';
$pg_type[1026] = '_filename';
$pg_type[1027] = '_polygon';
$pg_type[1033] = 'aclitem';
$pg_type[1034] = '_aclitem';
$pg_type[1039] = '_char2';
$pg_type[1040] = '_char4';
$pg_type[1041] = '_char8';
$pg_type[1042] = 'bpchar';
$pg_type[1043] = 'varchar';
$pg_type[1082] = 'date';
$pg_type[1083] = 'time';
$pg_type[1182] = '_date';
$pg_type[1183] = '_time';
$pg_type[1184] = 'datetime';
$pg_type[1185] = '_datetime';
$pg_type[1186] = 'timespan';
$pg_type[1187] = '_timespan';
$pg_type[1296] = 'timestamp';

1;
